          <%= @hostname %>
*********                            ******************************************
* This system is a restricted resource and property.                          *
* Use your administrator assigned user-id to access.                          *
* Unauthorized use and/or misuse of this system and services may constitute   *
* a breach of International criminal law, and could lead to legal             *
* disciplinary actions.                                                       *
*                                                                             *
* Individuals using this system without authority or in excess of their       *
* authority are subject to having all their activities on this system         *
* monitored and recorded or examined by any authorized person, including law  *
* enforcement, as system personnel deem appropriate.                          *
*                                                                             *
*                           LOG OFF IMMEDIATELY                               *
*                                                                             *
*******************************************************************************
